# -*- coding: utf-8 -*-

from copy import copy
from tools import trace, timer

from Model.DB import SQLSubModel
from Model.InitialConditions.InitialConditions import InitialConditions

class InitialConditionsDict(SQLSubModel):
    _sub_classes = [
        InitialConditions,
    ]

    def __init__(self, status = None):
        super(InitialConditionsDict, self).__init__()

        self._status = status

        self._reach = {}

    @classmethod
    def _sql_create(cls, execute):
        return cls._create_submodel(execute)

    @classmethod
    def _sql_update(cls, execute, version):
        return cls._update_submodel(execute, version)

    @classmethod
    def _sql_load(cls, execute, data = None):
        new = cls(status = data["status"])

        for reach in data["edges"]:
            data["reach"] = reach

            ic = InitialConditions._sql_load(
                execute,
                data = data
            )

            if ic is not None:
                new._reach[reach] = ic

        return new

    def _sql_save(self, execute, data = None):
        ok = True
        if data is None:
            data = {}

        execute("DELETE FROM initial_conditions")

        for reach in self._reach:
            data["reach"] = reach
            ok &= self._reach[reach]._sql_save(execute, data)

        return ok

    def __len__(self):
        return len(self._reach)

    def is_defined(self, reach):
        return reach in self._reach

    def get(self, reach):
        if reach in self._reach:
            return self._reach[reach]

        new = self.new(reach)
        self.set(reach, new)
        return new

    def set(self, reach, new):
        self._reach[reach] = new
        self._status.modified()

    def new(self, reach):
        new = InitialConditions(reach = reach, status = self._status)
        self.set(reach, new)
        return new
